#!/bin/ruby
# -*- coding: sjis -*-
=begin
----------------------------------------------------------
--- VoiceGet  ---
					Ver.1.0 
-------------
 Usage:
 $ ruby voiceget.rb wordlist.txt
-------------
Ruby version required is "ruby 2.1" or later.
	http://rubyinstaller.org/downloads/
	http://dl.bintray.com/oneclick/rubyinstaller/rubyinstaller-2.1.6.exe
-------------
History
	2015/07: First release v1.0 by audin.

=end

require 'open-uri'
require 'openssl'
require "fileutils"

$ROOT_NAME		= "data/wavvoice/cobuild_mp3"
$VOICE_BASE_URL = "https://ssl.gstatic.com/dictionary/static/sounds/de/0"

class VoiceGet
	def initialize
		@existCount = 0
		@totalWords = 0
	end

	def getWord( eword )
		res = true
		begin
			raise if ( eword == nil ) || ( eword.size == 0)
			@totalWords += 1
			voiceWord		= eword.strip
			voiceUrl		= $VOICE_BASE_URL	+ "/" + voiceWord + ".mp3"
			voiceDir		= $ROOT_NAME		+ "/" + voiceWord.downcase[0]

			saveMp3Name		= voiceDir + "/" + voiceWord + "_" + ".mp3"  
			if !File.exists?( saveMp3Name )
					open( voiceUrl, :ssl_verify_mode => OpenSSL::SSL::VERIFY_NONE ) do |data|
						mp3 =  data.read           
						FileUtils.mkdir_p(voiceDir) 
						open(saveMp3Name, 'wb') do | fout |     
							fout.write( mp3 )          
						end
					end
					@existCount += 1
			else
				@existCount += 1
			end
		rescue
			res = false
		end
		return res 
	end

	def getTotlalWords
		return @totalWords
	end

	def getExistCount
		return @existCount	
	end
end



if $0 == __FILE__
=begin
 Usage:

 $ ruby voiceget.rb wordlist.txt

 |-------------- Input text format is as follows: ---------- |
  english word(s) ,
  english word(s) ,
  .....
  "english word(s)",
  .....
=end
	if ARGV.size == 0 
		puts "Error: Argument!"
	else
		puts "[ Getting voices ... ]\n"
	 	wordListName = ARGV[0]
		voice = VoiceGet.new
		open( wordListName,"r" ).each do | line |
			res = ""
			# eword is 'single word' or 'words".
			eword = line.split(",")[0].strip.gsub(/\"/,"").strip.gsub(/ /,"_")
			if eword.size > 0
				if !voice.getWord( eword )
					res = "Fail"
				end
				printf("\n%04d / %04d: [%4s] %s",
						voice.getExistCount,
						voice.getTotlalWords, 
						res.to_s,
						eword )            
				STDOUT.flush
			end
		end
		printf("\n\n Available voices / Total words = %d / %d",
			   voice.getExistCount,
			   voice.getTotlalWords)
		printf("\n\n Voices Folder = %s",$ROOT_NAME)
		puts "\n\n[ End. ]\n"
	end

end



=begin

Copyright (c) 2015, audin
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, 
   this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, 
   this list of conditions and the following disclaimer in the documentation 
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=end


